@@ -8,7 +8,7 @@ around 'format_result' => sub {
    my $self = shift;
    my @to_dump = @_;
    my $out;
-   if (@to_dump != 1 || ref $to_dump[0]) {
+   if (@to_dump > 1 || ref $to_dump[0]) {
       if (@to_dump == 1 && overload::Method($to_dump[0], '""')) {
          $out = "@to_dump";
       } else {
